#include <bits/stdc++.h>
using namespace std;

typedef long long ll;
typedef pair<int, int> pii;

#define NONE -1

struct Node {
	vector<int> next;
	int back, length;
	int max_word;
	
	Node () : next(26, NONE), back(NONE), length(NONE), max_word(NONE) {}
};

struct Trie {
	vector<Node> V;
	
	Trie () : V(1) {
		V[0].length = 0;
	}
	
	void insert (int curr, string& str, int pos) {
		if (pos >= (int)str.size()) {
			V[curr].max_word = V[curr].length;
			return;
		}
		int ch = str[pos] - 'a';
		int next = V[curr].next[ch];
		if (next == NONE) {
			V[curr].next[ch] = V.size();
			V.push_back(Node());
			V.back().length = V[curr].length + 1;
			next = V[curr].next[ch];
		}
		insert(next, str, pos+1);
	}
	void insert (string& str) {
		insert(0, str, 0);
	}
	
	void backlinks () {
		queue<int> Q;
		Q.push(0);
		while (!Q.empty()) {
			int curr = Q.front();
			Q.pop();
			for (int ch = 0; ch < 26; ch++) {
				if (V[curr].next[ch] == NONE) {
					continue;
				}
				int child = V[curr].next[ch];
				Q.push(child);
				
				// calculate backlink for child
				int k = V[curr].back;
				while (k != NONE && V[k].next[ch] == NONE) {
					k = V[k].back;
				}
				int ch_back = (k == NONE ? 0 : V[k].next[ch]);
				V[child].back = ch_back;
				V[child].max_word = max(V[child].max_word, V[ch_back].max_word);
			}
		}
	}
	
	int next_state (int curr, int ch) {
		while (curr != NONE && V[curr].next[ch] == NONE) {
			curr = V[curr].back;
		}
		if (curr == NONE) {
			return 0;
		}
		return V[curr].next[ch];
	}
};

void print (vector<int>& V) {
	for (auto x : V) {
		cerr << x << " ";
	}
	cerr << "\n";
}

int main () {
	ios::sync_with_stdio(false);
	int l;
	string tgt;
	cin >> l >> tgt;
	int n = tgt.size();
	
	// construct trie
	Trie T;
	for (int i = 0; i < l; i++) {
		string str;
		cin >> str;
		T.insert(str);
	}
	T.backlinks();
	
	// calculate edges
	vector<int> edges(n, NONE);
	int curr = 0;
	for (int i = 0; i < n; i++) {
		int ch = tgt[i] - 'a';
		curr = T.next_state(curr, ch);
		if (T.V[curr].max_word == NONE) {
			continue;
		}
		int wlen = T.V[curr].max_word;
		int index =  i + 1 - wlen;
		edges[index] = max(edges[index], i + 1);
	}
	// print(edges);
	
	// calculate result based on edges
	int i = 0, lim = 0, res = 0;
	while (i < n && lim < n) {
		res += 1;
		int next_lim = lim;
		for (int j = i; j <= lim; j++) {
			next_lim = max(edges[j], next_lim);
		}
		// cerr << "i = " << i << ", lim = " << lim << ", next_lim = " << next_lim << "\n";
		if (lim == next_lim) {
			cout << "-1\n";
			return 0;
		}
		i = lim;
		lim = next_lim;
	}
	cout << res << "\n";
}
